@@ -141,15 +141,33 @@ Licensed under the MIT license.
 """
 import sys
 import threading
-from threading import Condition, Timer
+from threading import Condition
 import time
-from DBUtils import PooledDB as Pool_db
-import logging
+from dbutils import pooled_db as pool_db
+from sys import version_info
 
-__version__ = '1.0'
+py_version = version_info[:2]
+
+__version__ = '2.0.1'
+
+if py_version == (2, 7):
+    from threading import _Timer as Timer
+else:
+    from threading import Timer
+# from threading import Timer
 
 
-class PooledDB(Pool_db.PooledDB):
+class RepeatingTimer(Timer):
+    """
+    重写 Timer run方法 以实现Timer线程常驻，循环执行
+    """
+    def run(self):
+        while not self.finished.is_set():
+            self.finished.wait(self.interval)
+            self.function(*self.args, **self.kwargs)
+
+
+class PooledDB(pool_db.PooledDB):
     """Pool for DB-API 2 connections.
 
     After you have created the connection pool, you can use
@@ -233,7 +251,7 @@ class PooledDB(Pool_db.PooledDB):
             else:
                 threadsafety = 0
         if not threadsafety:
-            raise Pool_db.NotSupportedError("Database module is not thread-safe.")
+            raise pool_db.NotSupportedError("Database module is not thread-safe.")
         self._creator = creator
         self._args, self._kwargs = args, kwargs
         self._blocking = blocking
@@ -246,7 +264,7 @@ class PooledDB(Pool_db.PooledDB):
         self.testOnBorrow = test_on_borrow
         self.testIdle = test_idle
         self.validationSql = self.def_validate_sql if not validation_sql else validation_sql
-        self.idleCheckTime = 0 if int(idle_check_time) < 0 else int(idle_check_time)
+        self.idleCheckTime = 60 if int(idle_check_time) < 0 else int(idle_check_time)
         self.validateTimeOut = 1 if int(validate_timeout) < 0 else int(validate_timeout)
         self.maxWaitTime = 5 if int(max_wait_time) < 0 else int(max_wait_time)
         # 新增项处理结束
@@ -286,7 +304,8 @@ class PooledDB(Pool_db.PooledDB):
             idle.pop().close()  # 后进先出
         # 开启空闲线程检查
         if self.testIdle and self.idleCheckTime > 0:
-            t = Timer(self.idleCheckTime, self.start_check_idle, [self.idleCheckTime])
+            t = RepeatingTimer(self.idleCheckTime, self.start_check_idle, [self.idleCheckTime])
+            t.setDaemon(True)
             t.start()
 
     def start_check_idle(self, time_out):
@@ -309,7 +328,7 @@ class PooledDB(Pool_db.PooledDB):
             loop_times = len(self._idle_cache)
             while loop_times > 0:
                 loop_times -= 1
-                con = None
+                flag, con =False, None
                 try:  # first try to get it from the idle cache
                     con = self._idle_cache.pop(0)
                     flag = self._validate_connection(con, False)
@@ -326,9 +345,7 @@ class PooledDB(Pool_db.PooledDB):
         except Exception as e:
             self._log("check idle conn error:%s" % e, "error")
             return False
-        finally:
-            t = Timer(time_out, self.start_check_idle, [time_out])
-            t.start()
+
 
     def connection(self, shareable=True):
         # self._lock.acquire()
@@ -343,13 +360,13 @@ class PooledDB(Pool_db.PooledDB):
                     t.stop()
                     error = "%s获取新连接失败，获取超时%s,thread=%s,flag is%s,error:%s" % (
                         threading.currentThread().getName(), time.time()-start, t.getName(), t.isAlive(), t.error)
-                    raise Pool_db.PooledDBError(error)
+                    raise pool_db.PooledDBError(error)
             else:
                 conn = self.new_connection(shareable)
                 # conn = super(PooledDB, self).connection(shareable)
             # self._lock.notify()
         except Exception as e:
-            raise Pool_db.InvalidConnection(e)
+            raise pool_db.InvalidConnection(e)
         # finally:
         #     self._lock.release()
         return conn
@@ -366,7 +383,7 @@ class PooledDB(Pool_db.PooledDB):
             return conn
         except Exception as e:
             self.close_conn(conn)
-            raise Pool_db.PooledDBError("get_validated_conn error", e)
+            raise pool_db.PooledDBError("get_validated_conn error", e)
 
     def new_connection(self, shareable=True):
         """
@@ -397,7 +414,7 @@ class PooledDB(Pool_db.PooledDB):
                         self._log("get cached conn timeout=%s" % (time.time() - star_time))
                         con._ping_check()  # check this connection
                         self._log("check cached conn end timeout=%s" % (time.time() - star_time))
-                    con = Pool_db.SharedDBConnection(con)
+                    con = pool_db.SharedDBConnection(con)
                     self._connections += 1
                 else:  # shared cache full or no more connections allowed
                     self._shared_cache.sort()  # least shared connection first
@@ -415,7 +432,7 @@ class PooledDB(Pool_db.PooledDB):
                 self._lock.notify()
             finally:
                 self._lock.release()
-            con = Pool_db.PooledSharedDBConnection(self, con)
+            con = pool_db.PooledSharedDBConnection(self, con)
         else:  # try to get a dedicated connection
             self._lock.acquire()
             try:
@@ -432,7 +449,7 @@ class PooledDB(Pool_db.PooledDB):
                     self._log("get cached conn timeout=%s" % (time.time() - star_time))
                     con._ping_check()  # check connection
                     self._log("check cached conn end timeout=%s" % (time.time() - star_time))
-                con = Pool_db.PooledDedicatedDBConnection(self, con)
+                con = pool_db.PooledDedicatedDBConnection(self, con)
                 self._connections += 1
             finally:
                 self._lock.release()
@@ -522,7 +539,6 @@ def close_cursor(cus):
         pass
 
 
-
 class ResultThread(threading.Thread):
     def __init__(self, fun, *args, **kwargs):
         threading.Thread.__init__(self)
@@ -546,3 +562,4 @@ class ResultThread(threading.Thread):
             self.result = self.fun(*self.args, **self.kwargs)
         except:
             self.error = sys.exc_info()
+
